@@ -1,6 +1,10 @@
 """Settings that need to be set in order to run the tests."""
+import logging
 import os
 
+
+logging.getLogger('factory').setLevel(logging.WARN)
+
 DEBUG = True
 FILER_DEBUG = True
 
@@ -15,7 +19,7 @@ DATABASES = {
 
 USE_I18N = True
 
-LANGUAGE_CODE = 'en-us'
+LANGUAGE_CODE = 'en'
 
 LANGUAGES = (
     ('en', 'English'),
@@ -77,7 +81,7 @@ TEMPLATE_CONTEXT_PROCESSORS = (
 THUMBNAIL_PROCESSORS = (
     'easy_thumbnails.processors.colorspace',
     'easy_thumbnails.processors.autocrop',
-    #'easy_thumbnails.processors.scale_and_crop',
+    # 'easy_thumbnails.processors.scale_and_crop',
     'filer.thumbnail_processors.scale_and_crop_with_subject_location',
     'easy_thumbnails.processors.filters',
 )
@@ -92,6 +96,7 @@ EXTERNAL_APPS = [
     'django.contrib.staticfiles',
     'django.contrib.sitemaps',
     'django.contrib.sites',
+    'django_libs',
     'django_nose',
     'djangocms_text_ckeditor',
     'cms',
@@ -118,7 +123,11 @@ CMS_SEO_FIELDS = True
 CMS_MENU_TITLE_OVERWRITE = True
 CMS_FRONTEND_LANGUAGES = ('en', 'de', )
 CMS_TEMPLATES = (
-    ('standard.html', 'Standard'),
+    ('base.html', 'Standard'),
 )
 
 SECRET_KEY = 'foobar'
+
+SOUTH_MIGRATION_MODULES = {
+    'easy_thumbnails': 'easy_thumbnails.south_migrations',
+}
